@@ -24,6 +24,15 @@ class TestODict:
         for i in expected:
             assert out.find(i) >= 0
 
+    def test_getset_state(self):
+        self.od.add("foo", 1)
+        self.od.add("foo", 2)
+        self.od.add("bar", 3)
+        state = self.od.get_state()
+        nd = odict.ODict.from_state(state)
+        assert nd == self.od
+        nd.load_state(state)
+
     def test_dictToHeader2(self):
         self.od["one"] = ["uno"]
         expected1 = "one: uno\r\n"
@@ -41,14 +50,6 @@ class TestODict:
         assert h.match_re("two: due")
         assert not h.match_re("nonono")
 
-    def test_getset_state(self):
-        self.od.add("foo", 1)
-        self.od.add("foo", 2)
-        self.od.add("bar", 3)
-        state = self.od._get_state()
-        nd = odict.ODict._from_state(state)
-        assert nd == self.od
-
     def test_in_any(self):
         self.od["one"] = ["atwoa", "athreea"]
         assert self.od.in_any("one", "two")
@@ -58,6 +59,20 @@ class TestODict:
         assert not self.od.in_any("one", "TWO")
         assert self.od.in_any("one", "TWO", True)
 
+    def test_iter(self):
+        assert not [i for i in self.od]
+        self.od.add("foo", 1)
+        assert [i for i in self.od]
+
+    def test_keys(self):
+        assert not self.od.keys()
+        self.od.add("foo", 1)
+        assert self.od.keys() == ["foo"]
+        self.od.add("foo", 2)
+        assert self.od.keys() == ["foo"]
+        self.od.add("bar", 2)
+        assert len(self.od.keys()) == 2
+
     def test_copy(self):
         self.od.add("foo", 1)
         self.od.add("foo", 2)
@@ -117,3 +132,13 @@ class TestODictCaseless:
         self.od.add("bar", 3)
         del self.od["foo"]
         assert len(self.od) == 1
+
+    def test_keys(self):
+        assert not self.od.keys()
+        self.od.add("foo", 1)
+        assert self.od.keys() == ["foo"]
+        self.od.add("Foo", 2)
+        assert self.od.keys() == ["foo"]
+        self.od.add("bar", 2)
+        assert len(self.od.keys()) == 2
+
